==> fdosdf-3.2.1.tar.gz: OpenSource_FDO/Providers/SDF/Docs/doc_src/group_and_page_definitions/define_pages.h <==
/*! \mainpage Introduction
<div class="mainpage">
<!-- This is the index.html page that the user first sees. -->

<p>The Feature Data Objects (FDO) API provides access to data in a 
data store. A provider is a specific implementation of the FDO API 
that provides access to data in a particular data store. The FDO 
Provider for SDF provides FDO with access to an SDF-based data store.

<p>The Autodesk SDF file format is a standalone, file-based spatial database 
format that supports multiple features classes and properties in a single file, 
and provides spatial indexing, interoperability, and high performance for 
large data sets.
</p>

<p>The SDF file format has the following characteristics:
</p>
<ul>
  <li>SDF files can be read on different platforms.
  <li>One schema in a single SDF file supports multiple feature classes.
  <li>The SDF file has its own spatial indexing.
  <li>SDF files can store geometric and non-geometric data with minimum overhead.
  <li>The SDF file format supports a single writer at any time, with multiple readers.
</ul>

<p>An SDF schema can support the following:
</p>
<ul>
  <li>Auto ID generation
  <li>Exclusive value range constraints
  <li>Null value constraints
  <li>Spatial contexts
  <li>These geometry types: point, line string, polygon, multi-point, multi-line 
  string, multi-polygon, curve string, curve polygon, multi-curve string, 
  multi-curve polygon, linear ring, line string segment, circular arc segment, and ring.
</ul>

<p>
For more information, see <i>The Essential FDO</i> (FET_TheEssentialFDO.pdf) 
and the <i>FDO Developer's Guide</i> (FDG_FDODevGuide.pdf).
</p>

<br>
</div>
*/

==> fdosdf-3.6.0_5104.tar.gz: OpenSource_FDO/Providers/SDF/Docs/doc_src/group_and_page_definitions/define_pages.h <==
/*! \mainpage Introduction
<div class="mainpage">
<!-- This is the index.html page that the user first sees. -->

<p>The Feature Data Objects (FDO) API provides access to data in a 
data store. A provider is a specific implementation of the FDO API 
that provides access to data in a particular data store. The FDO 
Provider for SDF provides FDO with access to an SDF-based data store.

<p>The Autodesk SDF file format is a standalone, file-based spatial database 
format that supports multiple features classes and properties in a single file, 
and provides spatial indexing, interoperability, and high performance for 
large data sets.
</p>

<p>The SDF file format has the following characteristics:
</p>
<ul>
  <li>SDF files can be read on different platforms.
  <li>One schema in a single SDF file supports multiple feature classes.
  <li>The SDF file has its own spatial indexing.
  <li>SDF files can store geometric and non-geometric data with minimum overhead.
  <li>The SDF file format supports a single writer at any time, with multiple readers.
</ul>

<p>An SDF schema can support the following:
</p>
<ul>
  <li>Auto ID generation
  <li>Exclusive value range constraints
  <li>Null value constraints
  <li>Spatial contexts
  <li>These geometry types: point, line string, polygon, multi-point, multi-line 
  string, multi-polygon, curve string, curve polygon, multi-curve string, 
  multi-curve polygon, linear ring, line string segment, circular arc segment, and ring.
</ul>

<p>
For more information, see <i>The Essential FDO</i>
and the <i>FDO Developer's Guide</i>.
</p>

<br>
</div>
*/
